@@ -42,9 +42,14 @@ function(data,C,order)  {
 			w = matrix(gamma[1:(T-1),j], 1,T-1)
 		    wobs = obs[1:(T-1),] * repmat(t(w),1,d*order)
             wobs_1 = obs[2:T,] * repmat(t(w),1,d*order)
+             if (is.na(sum(obs))) {
+            	wobs[is.na(wobs)] = 0
+            	wobs_1[is.na(wobs_1)] = 0
+            	obs[is.na(obs)] = 0
+            }           
             m[,j] = m[,j] + apply(wobs,2,sum)
             m_1[,j] = m_1[,j] + apply(wobs_1, 2,sum)
-            op[,,j] = op[,,j] + t(wobs) %*% obs[1:T-1,]
+            op[,,j] = op[,,j] + t(wobs) %*% obs[1:(T-1),]
             op_1[,,j] = op_1[,,j] + t(wobs) %*% obs[2:T,]
             op_2[,,j] = op_2[,,j] + t(wobs_1) %*% obs[2:T,]
          }
@@ -56,8 +61,10 @@ function(data,C,order)  {
 																		
 	for (j in 1:M) { 
 		Cxx = postmix[j]*op[,,j] - m[,j]%*%t(m[,j])
+		if (det(Cxx)<=0) {Cxx = Cxx+1e-4*diag(1,d)}
         Cxy = postmix[j]*op_1[,,j] - m[,j]%*%t(m_1[,j])
-        A2tmp = t(Cxy)%*%solve(Cxx) 
+        #A2tmp = t(Cxy)%*%solve(Cxx) 
+        A2tmp = t(solve(Cxx,Cxy)) 
         tmp = (m_1[,j]-(A2tmp)%*%m[,j])/postmix[j] 
         moy[j,1:d] = tmp[1:d] 
         op_1[,,j] = t(as.matrix(op_1[,,j]))
